@@ -14,17 +14,20 @@ from .hub_sensors import HubSensorsFactory
 from .hub_options import HubOptions
 
 class Hub:
-    def __init__(self, options: HubOptions, domain: str, state_machine):
+    def __init__(self, options: HubOptions, domain: str, state_machine, chargerobj):
+        self.state_machine = state_machine
+        self.domain = domain
+
         self.options: HubOptions = options
         self.sensors = HubSensorsFactory.create(self.options)
         self.timer: Timer = Timer()
-        #self.threshold = ThresholdFactory.create(self.options)
-        #self.prediction = Prediction(self.options)
-        self.locale: LocaleData(self.options.locale, domain)
-        #chargecontroller: ChargeControllerBase = field(init=False)
-        #hours: Hours = field(init=False)
+        self.hours: Hours = HourselectionFactory.create(self)
+        self.threshold = ThresholdFactory.create(self)
+        self.prediction = Prediction(self)
 
-        self.sensors.setup(state_machine=state_machine, options=options, domain=domain)
+        #chargecontroller: ChargeControllerBase = field(init=False)
+
+        self.sensors.setup(state_machine=state_machine, options=options, domain=domain, chargerobject=chargerobj)
         self.sensors.init_hub_values()
 
 
