@@ -1,4 +1,4 @@
-from dataclasses import dataclass
+from dataclasses import dataclass, field
 from datetime import datetime
 
 from ..locale.free_charge import FreeChargePattern
@@ -18,12 +18,12 @@ class Locale_Type:
     query_model: LocaleQuery
     free_charge_pattern: FreeChargePattern = None
     peak_cycle: str = HOURLY
-    converted: bool = False #transition key to remove sql-dependency
+    #converted: bool = False #transition key to remove sql-dependency
+    is_quarterly: bool = field(init=False, repr=False)
 
     def free_charge(self, mockdt: datetime=datetime.min) -> bool:
         if self.free_charge_pattern is None:
             return False
-
         now = datetime.now() if mockdt is datetime.min else mockdt
         return self.free_charge_pattern.free_charge(now)
 
@@ -31,3 +31,4 @@ class Locale_Type:
         return self.peak_cycle == QUARTER_HOURLY
 
 
+
