@@ -15,7 +15,10 @@ class SessionPrice:
 
     @property
     def total_energy(self) -> float:
-        return round(self.get_status()["energy"]["value"], 5)
+        return round(self.get_status()["energy"]["value"], 3)
+
+    def reset(self):
+        self.__init__()
 
     def terminate(self, mock_time: float=None):
         print("called terminate")
@@ -43,15 +46,21 @@ class SessionPrice:
         self._set_delta(mock_time)
         p = PowerReading(self._price, self._current_power, self._time_delta)
         self._readings.append(p)
-        self._current_power = float(power)
+        try:
+            self._current_power = float(power)
+        except:
+            self._current_power = 0
 
-    def update_price(self, price: float, mock_time: float=None):
+    def update_price(self, price: any, mock_time: float=None):
         if self._current_power > 0:
             self.update_power_reading(
                 power=self._current_power,
                 mock_time=mock_time
             )
-        self._price = price
+        try:
+            self._price = float(price)
+        except:
+            self._price = 0
 
     def _set_delta(self, mock_time: float=None) -> None:
         now = mock_time or time.time()
@@ -64,8 +73,37 @@ class SessionPrice:
 
     @property
     def total_price(self) -> float:
-        return self.get_status()["price"]
+        return round(self.get_status()["price"], 3)
 
     @total_price.setter
     def total_price(self, val):
         self.total_price = val
+
+
+class Session:
+    def __init__(self, charger):
+        self._charger = charger
+        self.core = SessionPrice()
+        self.core._set_delta()
+
+    @property
+    def session_energy(self):
+        return self.core.total_energy
+
+    @session_energy.setter
+    def session_energy(self, val):
+        self.core.update_power_reading(val)
+        self.update_session_pricing()
+
+    @property
+    def session_price(self):
+        return self.core.total_price
+
+    @session_price.setter
+    def session_price(self, val):
+        self.core.update_price(val)
+        self.update_session_pricing()
+
+    def update_session_pricing(self):
+        if self._charger.session_is_active is False:
+            self.core.terminate()
\ No newline at end of file
